"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insighttoolinput import InsightToolInput, InsightToolInputTypedDict
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class InsightsToolUpdateRequestTypedDict(TypedDict):
    tool_id: int
    insight_tool_input: InsightToolInputTypedDict


class InsightsToolUpdateRequest(BaseModel):
    tool_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    insight_tool_input: Annotated[
        InsightToolInput,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from syllable_sdk import models, utils
from syllable_sdk._hooks import HookContext
from syllable_sdk.insights_tools import InsightsTools
from syllable_sdk.types import OptionalNullable, UNSET
from syllable_sdk.utils import get_security_from_env
from syllable_sdk.workflows import Workflows
from typing import Any, List, Mapping, Optional


class InsightsSDK(BaseSDK):
    r"""Operations related to insights results. An insight is a tool that processes          conversation data to extract information and generate reports."""

    workflows: Workflows
    r"""Operations related to insights workflows. An workflow is series of tool           invocations that processes conversation data to extract information and generate reports."""
    tools: InsightsTools
    r"""Operations related to insights tools. An insight is a tool that processes           conversation data to extract information and generate reports."""

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.workflows = Workflows(self.sdk_configuration)
        self.tools = InsightsTools(self.sdk_configuration)

    def list(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.InsightsProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.InsightsProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.InsightsProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseInsightsOutput:
        r"""Insights List

        List the evaluated insights for sessions.

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.InsightsListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/insights/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="insights_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.ListResponseInsightsOutput
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.InsightsProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.InsightsProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.InsightsProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseInsightsOutput:
        r"""Insights List

        List the evaluated insights for sessions.

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.InsightsListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/insights/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="insights_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, models.ListResponseInsightsOutput
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.HTTPValidationErrorData
            )
            raise models.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
from syllable_sdk import models, utils
from syllable_sdk._hooks import SDKHooks
from syllable_sdk.agents import Agents
from syllable_sdk.channels import Channels
from syllable_sdk.conversations import Conversations
from syllable_sdk.custom_messages import CustomMessages
from syllable_sdk.dashboards import Dashboards
from syllable_sdk.data_sources import DataSources
from syllable_sdk.events import Events
from syllable_sdk.incidents import Incidents
from syllable_sdk.insights_sdk import InsightsSDK
from syllable_sdk.language_groups import LanguageGroups
from syllable_sdk.outbound import Outbound
from syllable_sdk.prompts import Prompts
from syllable_sdk.services import Services
from syllable_sdk.session_debug import SessionDebug
from syllable_sdk.session_labels import SessionLabels
from syllable_sdk.sessions import Sessions
from syllable_sdk.takeouts import Takeouts
from syllable_sdk.tools import Tools
from syllable_sdk.types import OptionalNullable, UNSET
from typing import Any, Callable, Dict, Optional, Union, cast
import weakref


class SyllableSDK(BaseSDK):
    r"""SyllableSDK:
    # Syllable Platform SDK

    Syllable SDK gives you the power of awesome AI agentry. 🚀

    ## Overview

    The Syllable SDK provides a comprehensive set of tools and APIs to integrate powerful AI
    capabilities into your communication applications. Whether you're building chatbots, virtual
    assistants, or any other AI-driven solutions, Syllable SDK has got you covered.

    ## Features

    - **Natural Language Processing (NLP)**: Understand and generate human language with ease.
    - **Machine Learning Models**: Leverage pre-trained models or train your own custom models.
    - **Speech Recognition**: Convert speech to text and vice versa.
    - **Data Analytics**: Analyze and visualize data to gain insights.
    - **Integration**: Seamlessly integrate with other services and platforms.


    """

    agents: Agents
    r"""Operations related to agent configuration. When a user interacts with the           Syllable system, they do so by communicating with an agent.           An agent is linked to a prompt, a custom message, and one or more channel targets to           define its behavior and capabilities. For more information, see           [Console docs](https://docs.syllable.ai/workspaces/Agents)."""
    channels: Channels
    r"""Operations related to channel configuration.           A channel is an organization-level point of communication, like a phone number or a web           chat. A channel can be associated with an agent by creating a channel target linking           them."""
    conversations: Conversations
    r"""Operations related to conversations.           A conversation is a record of messages between a user and an agent, and is composed of           one or more sessions."""
    data_sources: DataSources
    r"""Operations related to data sources. A data source is a blob of text that           can be made available to an agent's general info tools to provide more context to the           agent when generating its responses. For more information, see           [Console docs](https://docs.syllable.ai/Resources/DataSources)."""
    events: Events
    r"""Operations related to events. An event represents a specific occurrence           during a session. Currently the API/SDK only supports fetching logged events."""
    incidents: Incidents
    r"""Operations related to incidents."""
    insights: InsightsSDK
    r"""Operations related to insights results. An insight is a tool that processes          conversation data to extract information and generate reports."""
    custom_messages: CustomMessages
    r"""Operations related to custom message configuration.           A custom message is a pre-configured message delivered by an agent as a greeting at the           beginning of a conversation. Multiple agents can use the same custom mesasage. A custom           message has one or more rules defined, which allow for different messages to be           dynamically selected and delivered at runtime based on the current time and either           date or day of the week. For more information, see           [Console docs](https://docs.syllable.ai/Resources/Messages)."""
    prompts: Prompts
    r"""Operations related to prompts. A prompt defines the behavior of an           agent by delivering instructions to the LLM about how the agent should behave.           A prompt can be linked to one or more agents. A prompt can also be linked to tools to           allow an agent using the prompt to use them. For more information, see           [Console docs](https://docs.syllable.ai/Resources/Prompts)."""
    services: Services
    r"""Operations related to service configuration. A service is a collection of           tools."""
    session_labels: SessionLabels
    r"""Operations related to labeling sessions with evaluations of quality and           descriptions of issues the user encountered or other details. For more information, see           [Console docs](https://docs.syllable.ai/workspaces/Sessions)."""
    sessions: Sessions
    r"""Operations related to sessions. A session is a building block of a           conversation. For more information, see           [Console docs](https://docs.syllable.ai/workspaces/Sessions)."""
    session_debug: SessionDebug
    tools: Tools
    r"""Operations related to tool configuration. A tool is a function that an           agent can call to perform actions like accessing databases, making API calls, or           processing data. For an agent to have access to a tool, the prompt associated with that           agent should be linked to the tool and include instructions to use it. For more           information, see [Console docs](https://docs.syllable.ai/Resources/Tools)."""
    dashboards: Dashboards
    r"""Operations related to dashboards. Currently the API/SDK           only supports fetching basic information about dashboards."""
    outbound: Outbound
    language_groups: LanguageGroups
    r"""Operations related to language groups. A language group is a           collection of language, voice, and DTMF configuration that can be linked to an agent to           define the languages and voices it supports. For more information, see           [Console docs](https://docs.syllable.ai/Resources/LanguageGroups)."""
    takeouts: Takeouts

    def __init__(
        self,
        api_key_header: Optional[
            Union[Optional[str], Callable[[], Optional[str]]]
        ] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param api_key_header: The api_key_header required for authentication
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client()
            client_supplied = False

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient()
            async_client_supplied = False

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(api_key_header):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(api_key_header=api_key_header())
        else:
            security = models.Security(api_key_header=api_key_header)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

        self._init_sdks()

    def _init_sdks(self):
        self.agents = Agents(self.sdk_configuration)
        self.channels = Channels(self.sdk_configuration)
        self.conversations = Conversations(self.sdk_configuration)
        self.data_sources = DataSources(self.sdk_configuration)
        self.events = Events(self.sdk_configuration)
        self.incidents = Incidents(self.sdk_configuration)
        self.insights = InsightsSDK(self.sdk_configuration)
        self.custom_messages = CustomMessages(self.sdk_configuration)
        self.prompts = Prompts(self.sdk_configuration)
        self.services = Services(self.sdk_configuration)
        self.session_labels = SessionLabels(self.sdk_configuration)
        self.sessions = Sessions(self.sdk_configuration)
        self.session_debug = SessionDebug(self.sdk_configuration)
        self.tools = Tools(self.sdk_configuration)
        self.dashboards = Dashboards(self.sdk_configuration)
        self.outbound = Outbound(self.sdk_configuration)
        self.language_groups = LanguageGroups(self.sdk_configuration)
        self.takeouts = Takeouts(self.sdk_configuration)

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomMessageProperties(str, Enum):
    ID = "id"
    NAME = "name"
    TEXT = "text"
    LABEL = "label"
    UPDATED_AT = "updated_at"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class PromptHistoryTypedDict(TypedDict):
    r"""Record of a change to a prompt. Values reflect post-change state."""

    timestamp: datetime
    r"""Timestamp of the change"""
    prompt_id: str
    r"""ID of the prompt"""
    prompt_text: str
    r"""Text of the prompt"""
    prompt_name: str
    r"""Name of the prompt"""
    user_email: str
    r"""Email address of the user who made the change"""
    prompt_description: NotRequired[Nullable[str]]
    r"""Description of the prompt"""
    llm_config: NotRequired[Nullable[str]]
    r"""String representation of LLM config for the prompt"""
    comments: NotRequired[Nullable[str]]
    r"""Comments describing the change"""


class PromptHistory(BaseModel):
    r"""Record of a change to a prompt. Values reflect post-change state."""

    timestamp: datetime
    r"""Timestamp of the change"""

    prompt_id: str
    r"""ID of the prompt"""

    prompt_text: str
    r"""Text of the prompt"""

    prompt_name: str
    r"""Name of the prompt"""

    user_email: str
    r"""Email address of the user who made the change"""

    prompt_description: OptionalNullable[str] = UNSET
    r"""Description of the prompt"""

    llm_config: OptionalNullable[str] = UNSET
    r"""String representation of LLM config for the prompt"""

    comments: OptionalNullable[str] = UNSET
    r"""Comments describing the change"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["prompt_description", "llm_config", "comments"]
        nullable_fields = ["prompt_description", "llm_config", "comments"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class CommunicationRequestRequestVariablesTypedDict(TypedDict):
    r"""Variables for request"""


class CommunicationRequestRequestVariables(BaseModel):
    r"""Variables for request"""


class CommunicationRequestTypedDict(TypedDict):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""
    target: str
    r"""Target phone number or email address"""
    request_variables: CommunicationRequestRequestVariablesTypedDict
    r"""Variables for request"""


class CommunicationRequest(BaseModel):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""

    target: str
    r"""Target phone number or email address"""

    request_variables: CommunicationRequestRequestVariables
    r"""Variables for request"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .targetmodes import TargetModes
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Optional, TYPE_CHECKING
from typing_extensions import NotRequired, TypedDict

if TYPE_CHECKING:
    from .agentresponse import AgentResponse, AgentResponseTypedDict


class ChannelTargetResponseTypedDict(TypedDict):
    r"""Response model for channel target operations.
    A channel target links a channel to an agent, allowing users to communicate with the agent
    through that channel. For more information, see
    [Console docs](https://docs.syllable.ai/Resources/Channels).
    """

    agent_id: int
    r"""The internal ID of the agent associated with the channel target"""
    channel_id: int
    r"""The internal ID of the channel associated with the channel target"""
    target: str
    r"""The name of the channel target. Must correspond to an organization-level target (available targets can be fetched from `/channels/available-targets`)."""
    target_mode: TargetModes
    r"""Available modes (communication methods) for channel targets."""
    id: int
    r"""The internal ID of the channel target"""
    channel_name: str
    r"""The name of the channel associated with the channel target"""
    updated_at: datetime
    r"""Timestamp of the most recent update to the channel target"""
    last_updated_by: str
    r"""Email of the user who last updated the channel target"""
    fallback_target: NotRequired[Nullable[str]]
    r"""The fallback for the channel target (currently only supported for \"voice\" mode)"""
    is_test: NotRequired[bool]
    r"""Whether the channel target is intended for testing. If true, any sessions created through this target will be labeled as a test session (i.e., will not be included in dashboard data and can easily be filtered out in the Sessions screen in the SyllableConsole)."""
    agent: NotRequired[Nullable["AgentResponseTypedDict"]]
    r"""Definition of the agent with which the channel target is associated."""


class ChannelTargetResponse(BaseModel):
    r"""Response model for channel target operations.
    A channel target links a channel to an agent, allowing users to communicate with the agent
    through that channel. For more information, see
    [Console docs](https://docs.syllable.ai/Resources/Channels).
    """

    agent_id: int
    r"""The internal ID of the agent associated with the channel target"""

    channel_id: int
    r"""The internal ID of the channel associated with the channel target"""

    target: str
    r"""The name of the channel target. Must correspond to an organization-level target (available targets can be fetched from `/channels/available-targets`)."""

    target_mode: TargetModes
    r"""Available modes (communication methods) for channel targets."""

    id: int
    r"""The internal ID of the channel target"""

    channel_name: str
    r"""The name of the channel associated with the channel target"""

    updated_at: datetime
    r"""Timestamp of the most recent update to the channel target"""

    last_updated_by: str
    r"""Email of the user who last updated the channel target"""

    fallback_target: OptionalNullable[str] = UNSET
    r"""The fallback for the channel target (currently only supported for \"voice\" mode)"""

    is_test: Optional[bool] = False
    r"""Whether the channel target is intended for testing. If true, any sessions created through this target will be labeled as a test session (i.e., will not be included in dashboard data and can easily be filtered out in the Sessions screen in the SyllableConsole)."""

    agent: OptionalNullable["AgentResponse"] = UNSET
    r"""Definition of the agent with which the channel target is associated."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["fallback_target", "is_test", "agent"]
        nullable_fields = ["fallback_target", "agent"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceDisplayName(str, Enum):
    r"""Display names of voices that Syllable supports."""

    ALEJANDRO = "Alejandro"
    ALICE = "Alice"
    ALLOY = "Alloy"
    ASH = "Ash"
    BILL = "Bill"
    BRIAN = "Brian"
    CALLUM = "Callum"
    CHARLIE = "Charlie"
    CHARLOTTE = "Charlotte"
    CHRIS = "Chris"
    CLARA = "Clara"
    CORAL = "Coral"
    DANIEL = "Daniel"
    ECHO = "Echo"
    ERIC = "Eric"
    FABLE = "Fable"
    GEORGE = "George"
    ISABELLA = "Isabella"
    JERRY = "Jerry"
    JESSICA = "Jessica"
    LAURA = "Laura"
    LIAM = "Liam"
    LILY = "Lily"
    LINA = "Lina"
    MARK = "Mark"
    MATILDA = "Matilda"
    MELANIE = "Melanie"
    MILA = "Mila"
    NOVA = "Nova"
    ONYX = "Onyx"
    RIVER = "River"
    ROGER = "Roger"
    SARAH = "Sarah"
    SAGE = "Sage"
    SHIMMER = "Shimmer"
    SIENNA = "Sienna"
    TARA = "Tara"
    WILL = "Will"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .agent_deleteop import AgentDeleteRequest, AgentDeleteRequestTypedDict
from .agent_get_by_idop import AgentGetByIDRequest, AgentGetByIDRequestTypedDict
from .agent_listop import AgentListRequest, AgentListRequestTypedDict
from .agentcreate import AgentCreate, AgentCreateTypedDict
from .agentlanguage import AgentLanguage, AgentLanguageTypedDict
from .agentproperties import AgentProperties
from .agentresponse import AgentResponse, AgentResponseTypedDict
from .agentsttprovider import AgentSttProvider
from .agenttooldefaults import AgentToolDefaults, AgentToolDefaultsTypedDict
from .agenttoolfielddefault import AgentToolFieldDefault, AgentToolFieldDefaultTypedDict
from .agentupdate import AgentUpdate, AgentUpdateTypedDict
from .agentvoice import AgentVoice, AgentVoiceTypedDict
from .agentvoicedisplayname import AgentVoiceDisplayName
from .agentvoicegender import AgentVoiceGender
from .agentvoicemodel import AgentVoiceModel
from .agentvoicevarname import AgentVoiceVarName
from .agentwaitsound import AgentWaitSound
from .apierror import APIError
from .available_targetsop import (
    AvailableTargetsRequest,
    AvailableTargetsRequestTypedDict,
)
from .availabletarget import AvailableTarget, AvailableTargetTypedDict
from .availabletargetproperties import AvailableTargetProperties
from .batchdetails import (
    BatchDetails,
    BatchDetailsTypedDict,
    StatusCounts,
    StatusCountsTypedDict,
)
from .batchproperties import BatchProperties
from .batchstatus import BatchStatus
from .body_outbound_batch_delete import (
    BodyOutboundBatchDelete,
    BodyOutboundBatchDeleteTypedDict,
)
from .body_outbound_batch_upload import (
    BodyOutboundBatchUpload,
    BodyOutboundBatchUploadTypedDict,
    File,
    FileTypedDict,
)
from .campaignproperties import CampaignProperties
from .channel import Channel, ChannelTypedDict
from .channel_targets_createop import (
    ChannelTargetsCreateRequest,
    ChannelTargetsCreateRequestTypedDict,
)
from .channel_targets_deleteop import (
    ChannelTargetsDeleteRequest,
    ChannelTargetsDeleteRequestTypedDict,
)
from .channel_targets_get_by_idop import (
    ChannelTargetsGetByIDRequest,
    ChannelTargetsGetByIDRequestTypedDict,
)
from .channel_targets_listop import (
    ChannelTargetsListRequest,
    ChannelTargetsListRequestTypedDict,
)
from .channel_targets_updateop import (
    ChannelTargetsUpdateRequest,
    ChannelTargetsUpdateRequestTypedDict,
)
from .channelproperties import ChannelProperties
from .channels_listop import ChannelsListRequest, ChannelsListRequestTypedDict
from .channelservices import ChannelServices
from .channeltargetcreaterequest import (
    ChannelTargetCreateRequest,
    ChannelTargetCreateRequestTypedDict,
)
from .channeltargetproperties import ChannelTargetProperties
from .channeltargetresponse import ChannelTargetResponse, ChannelTargetResponseTypedDict
from .channeltargetupdaterequest import (
    ChannelTargetUpdateRequest,
    ChannelTargetUpdateRequestTypedDict,
)
from .communicationbatch import CommunicationBatch, CommunicationBatchTypedDict
from .communicationbatchinput import (
    CommunicationBatchInput,
    CommunicationBatchInputTypedDict,
)
from .communicationrequest import (
    CommunicationRequest,
    CommunicationRequestRequestVariables,
    CommunicationRequestRequestVariablesTypedDict,
    CommunicationRequestTypedDict,
)
from .communicationrequestresult import (
    CommunicationRequestResult,
    CommunicationRequestResultRequestVariables,
    CommunicationRequestResultRequestVariablesTypedDict,
    CommunicationRequestResultTypedDict,
    Insights,
    InsightsTypedDict,
)
from .conversation import Conversation, ConversationTypedDict
from .conversationproperties import ConversationProperties
from .conversations_listop import (
    ConversationsListRequest,
    ConversationsListRequestTypedDict,
)
from .createtakeoutresponse import CreateTakeoutResponse, CreateTakeoutResponseTypedDict
from .custom_message_get_by_idop import (
    CustomMessageGetByIDRequest,
    CustomMessageGetByIDRequestTypedDict,
)
from .custom_messages_deleteop import (
    CustomMessagesDeleteRequest,
    CustomMessagesDeleteRequestTypedDict,
)
from .custom_messages_listop import (
    CustomMessagesListRequest,
    CustomMessagesListRequestTypedDict,
)
from .custommessagecreaterequest import (
    CustomMessageCreateRequest,
    CustomMessageCreateRequestTypedDict,
)
from .custommessageproperties import CustomMessageProperties
from .custommessageresponse import CustomMessageResponse, CustomMessageResponseTypedDict
from .custommessagerule import CustomMessageRule, CustomMessageRuleTypedDict
from .custommessageupdaterequest import (
    CustomMessageUpdateRequest,
    CustomMessageUpdateRequestTypedDict,
)
from .dashboard import Dashboard, DashboardTypedDict
from .dashboardproperties import DashboardProperties
from .dashboardresponse import DashboardResponse, DashboardResponseTypedDict
from .dashboardtokenresponse import (
    DashboardTokenResponse,
    DashboardTokenResponseTypedDict,
)
from .data_sources_deleteop import (
    DataSourcesDeleteRequest,
    DataSourcesDeleteRequestTypedDict,
)
from .data_sources_get_by_idop import (
    DataSourcesGetByIDRequest,
    DataSourcesGetByIDRequestTypedDict,
)
from .data_sources_listop import DataSourcesListRequest, DataSourcesListRequestTypedDict
from .datasourcecreaterequest import (
    DataSourceCreateRequest,
    DataSourceCreateRequestTypedDict,
)
from .datasourcedetailresponse import (
    DataSourceDetailResponse,
    DataSourceDetailResponseTypedDict,
)
from .datasourcemetadataresponse import (
    DataSourceMetadataResponse,
    DataSourceMetadataResponseTypedDict,
)
from .datasourceproperties import DataSourceProperties
from .datasourceupdaterequest import (
    DataSourceUpdateRequest,
    DataSourceUpdateRequestTypedDict,
)
from .dayofweek import DayOfWeek
from .dialogmessage import DialogMessage, DialogMessageTypedDict
from .dialogrole import DialogRole
from .dialogtoolcall import DialogToolCall, DialogToolCallTypedDict
from .event import Attributes, AttributesTypedDict, Event, EventTypedDict
from .eventproperties import EventProperties
from .events_listop import EventsListRequest, EventsListRequestTypedDict
from .generate_session_recording_urlsop import (
    GenerateSessionRecordingUrlsRequest,
    GenerateSessionRecordingUrlsRequestTypedDict,
)
from .get_session_data_by_session_idop import (
    GetSessionDataBySessionIDRequest,
    GetSessionDataBySessionIDRequestTypedDict,
)
from .get_session_data_by_sidop import (
    GetSessionDataBySidRequest,
    GetSessionDataBySidRequestTypedDict,
)
from .get_session_tool_call_result_by_idop import (
    GetSessionToolCallResultByIDRequest,
    GetSessionToolCallResultByIDRequestTypedDict,
)
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .incident_deleteop import IncidentDeleteRequest, IncidentDeleteRequestTypedDict
from .incident_get_by_idop import (
    IncidentGetByIDRequest,
    IncidentGetByIDRequestTypedDict,
)
from .incident_listop import IncidentListRequest, IncidentListRequestTypedDict
from .incidentcreaterequest import IncidentCreateRequest, IncidentCreateRequestTypedDict
from .incidentorganizationresponse import (
    IncidentOrganizationResponse,
    IncidentOrganizationResponseTypedDict,
)
from .incidentproperties import IncidentProperties
from .incidentresponse import IncidentResponse, IncidentResponseTypedDict
from .incidentupdaterequest import IncidentUpdateRequest, IncidentUpdateRequestTypedDict
from .insight_tool_get_by_idop import (
    InsightToolGetByIDRequest,
    InsightToolGetByIDRequestTypedDict,
)
from .insight_tool_listop import InsightToolListRequest, InsightToolListRequestTypedDict
from .insights_listop import InsightsListRequest, InsightsListRequestTypedDict
from .insights_tool_updateop import (
    InsightsToolUpdateRequest,
    InsightsToolUpdateRequestTypedDict,
)
from .insights_workflow_deleteop import (
    InsightsWorkflowDeleteRequest,
    InsightsWorkflowDeleteRequestTypedDict,
)
from .insights_workflow_get_by_idop import (
    InsightsWorkflowGetByIDRequest,
    InsightsWorkflowGetByIDRequestTypedDict,
)
from .insights_workflow_listop import (
    InsightsWorkflowListRequest,
    InsightsWorkflowListRequestTypedDict,
)
from .insights_workflow_updateop import (
    InsightsWorkflowUpdateRequest,
    InsightsWorkflowUpdateRequestTypedDict,
)
from .insightsoutput import (
    InsightsOutput,
    InsightsOutputTypedDict,
    JSONValue,
    JSONValueTypedDict,
)
from .insightsproperties import InsightsProperties
from .insightsworkflowqueuesession import (
    InsightsWorkflowQueueSession,
    InsightsWorkflowQueueSessionTypedDict,
)
from .insighttooldefinition import (
    InsightToolDefinition,
    InsightToolDefinitionTypedDict,
    ToolParameters,
    ToolParametersTypedDict,
    ToolResultSet,
    ToolResultSetTypedDict,
)
from .insighttoolinput import (
    InsightToolInput,
    InsightToolInputToolArguments,
    InsightToolInputToolArgumentsTypedDict,
    InsightToolInputTypedDict,
)
from .insighttooloutput import (
    InsightToolOutput,
    InsightToolOutputToolArguments,
    InsightToolOutputToolArgumentsTypedDict,
    InsightToolOutputTypedDict,
)
from .insighttoolproperties import InsightToolProperties
from .insighttooltestinput import InsightToolTestInput, InsightToolTestInputTypedDict
from .insightworkflowinput import (
    InsightWorkflowInput,
    InsightWorkflowInputConditions,
    InsightWorkflowInputConditionsTypedDict,
    InsightWorkflowInputTypedDict,
)
from .insightworkflowoutput import (
    InsightWorkflowOutput,
    InsightWorkflowOutputConditions,
    InsightWorkflowOutputConditionsTypedDict,
    InsightWorkflowOutputTypedDict,
)
from .insightworkflowproperties import InsightWorkflowProperties
from .inspectlatencyresponse import (
    InspectLatencyResponse,
    InspectLatencyResponseTypedDict,
)
from .internaltool import InternalTool, InternalToolTypedDict
from .language_groups_deleteop import (
    LanguageGroupsDeleteRequest,
    LanguageGroupsDeleteRequestTypedDict,
)
from .language_groups_get_by_idop import (
    LanguageGroupsGetByIDRequest,
    LanguageGroupsGetByIDRequestTypedDict,
)
from .language_groups_listop import (
    LanguageGroupsListRequest,
    LanguageGroupsListRequestTypedDict,
)
from .languagecode import LanguageCode
from .languageconfig import LanguageConfig, LanguageConfigTypedDict
from .languagegroupagentinfo import (
    LanguageGroupAgentInfo,
    LanguageGroupAgentInfoTypedDict,
)
from .languagegroupcreaterequest import (
    LanguageGroupCreateRequest,
    LanguageGroupCreateRequestTypedDict,
)
from .languagegroupproperties import LanguageGroupProperties
from .languagegroupresponse import LanguageGroupResponse, LanguageGroupResponseTypedDict
from .languagegroupupdaterequest import (
    LanguageGroupUpdateRequest,
    LanguageGroupUpdateRequestTypedDict,
)
from .latencycategory import LatencyCategory
from .latencyentry import LatencyEntry, LatencyEntryTypedDict
from .latencyunittype import LatencyUnitType
from .listresponse_agentresponse_ import (
    ListResponseAgentResponse,
    ListResponseAgentResponseTypedDict,
)
from .listresponse_availabletarget_ import (
    ListResponseAvailableTarget,
    ListResponseAvailableTargetTypedDict,
)
from .listresponse_channel_ import ListResponseChannel, ListResponseChannelTypedDict
from .listresponse_channeltargetresponse_ import (
    ListResponseChannelTargetResponse,
    ListResponseChannelTargetResponseTypedDict,
)
from .listresponse_communicationbatch_ import (
    ListResponseCommunicationBatch,
    ListResponseCommunicationBatchTypedDict,
)
from .listresponse_conversation_ import (
    ListResponseConversation,
    ListResponseConversationTypedDict,
)
from .listresponse_custommessageresponse_ import (
    ListResponseCustomMessageResponse,
    ListResponseCustomMessageResponseTypedDict,
)
from .listresponse_dashboardresponse_ import (
    ListResponseDashboardResponse,
    ListResponseDashboardResponseTypedDict,
)
from .listresponse_datasourcemetadataresponse_ import (
    ListResponseDataSourceMetadataResponse,
    ListResponseDataSourceMetadataResponseTypedDict,
)
from .listresponse_event_ import ListResponseEvent, ListResponseEventTypedDict
from .listresponse_incidentresponse_ import (
    ListResponseIncidentResponse,
    ListResponseIncidentResponseTypedDict,
)
from .listresponse_insightsoutput_ import (
    ListResponseInsightsOutput,
    ListResponseInsightsOutputTypedDict,
)
from .listresponse_insighttooloutput_ import (
    ListResponseInsightToolOutput,
    ListResponseInsightToolOutputTypedDict,
)
from .listresponse_insightworkflowoutput_ import (
    ListResponseInsightWorkflowOutput,
    ListResponseInsightWorkflowOutputTypedDict,
)
from .listresponse_languagegroupresponse_ import (
    ListResponseLanguageGroupResponse,
    ListResponseLanguageGroupResponseTypedDict,
)
from .listresponse_outboundcampaign_ import (
    ListResponseOutboundCampaign,
    ListResponseOutboundCampaignTypedDict,
)
from .listresponse_promptresponse_ import (
    ListResponsePromptResponse,
    ListResponsePromptResponseTypedDict,
)
from .listresponse_serviceresponse_ import (
    ListResponseServiceResponse,
    ListResponseServiceResponseTypedDict,
)
from .listresponse_session_ import ListResponseSession, ListResponseSessionTypedDict
from .listresponse_sessionlabel_ import (
    ListResponseSessionLabel,
    ListResponseSessionLabelTypedDict,
)
from .listresponse_toolresponse_ import (
    ListResponseToolResponse,
    ListResponseToolResponseTypedDict,
)
from .orderbydirection import OrderByDirection
from .outbound_batch_addop import (
    OutboundBatchAddRequest,
    OutboundBatchAddRequestTypedDict,
)
from .outbound_batch_deleteop import (
    OutboundBatchDeleteRequest,
    OutboundBatchDeleteRequestTypedDict,
)
from .outbound_batch_get_by_idop import (
    OutboundBatchGetByIDRequest,
    OutboundBatchGetByIDRequestTypedDict,
)
from .outbound_batch_listop import (
    OutboundBatchListRequest,
    OutboundBatchListRequestTypedDict,
)
from .outbound_batch_removeop import (
    OutboundBatchRemoveRequest,
    OutboundBatchRemoveRequestTypedDict,
)
from .outbound_batch_resultsop import (
    OutboundBatchResultsRequest,
    OutboundBatchResultsRequestTypedDict,
)
from .outbound_batch_updateop import (
    OutboundBatchUpdateRequest,
    OutboundBatchUpdateRequestTypedDict,
)
from .outbound_batch_uploadop import (
    OutboundBatchUploadRequest,
    OutboundBatchUploadRequestTypedDict,
)
from .outbound_campaign_get_by_idop import (
    OutboundCampaignGetByIDRequest,
    OutboundCampaignGetByIDRequestTypedDict,
)
from .outbound_campaign_listop import (
    OutboundCampaignListRequest,
    OutboundCampaignListRequestTypedDict,
)
from .outbound_campaign_updateop import (
    OutboundCampaignUpdateRequest,
    OutboundCampaignUpdateRequestTypedDict,
)
from .outboundcampaign import (
    OutboundCampaign,
    OutboundCampaignCampaignVariables,
    OutboundCampaignCampaignVariablesTypedDict,
    OutboundCampaignTypedDict,
)
from .outboundcampaigninput import (
    OutboundCampaignInput,
    OutboundCampaignInputCampaignVariables,
    OutboundCampaignInputCampaignVariablesTypedDict,
    OutboundCampaignInputTypedDict,
)
from .post_get_dashboardop import (
    PostGetDashboardRequest,
    PostGetDashboardRequestTypedDict,
)
from .post_list_dashboardop import (
    PostListDashboardRequest,
    PostListDashboardRequestTypedDict,
)
from .promptcreaterequest import PromptCreateRequest, PromptCreateRequestTypedDict
from .prompthistory import PromptHistory, PromptHistoryTypedDict
from .promptllmconfig import PromptLlmConfig, PromptLlmConfigTypedDict
from .promptllmprovider import PromptLlmProvider
from .promptproperties import PromptProperties
from .promptresponse import PromptResponse, PromptResponseTypedDict
from .prompts_deleteop import PromptsDeleteRequest, PromptsDeleteRequestTypedDict
from .prompts_get_by_idop import PromptsGetByIDRequest, PromptsGetByIDRequestTypedDict
from .prompts_historyop import PromptsHistoryRequest, PromptsHistoryRequestTypedDict
from .prompts_listop import PromptsListRequest, PromptsListRequestTypedDict
from .promptupdaterequest import PromptUpdateRequest, PromptUpdateRequestTypedDict
from .security import Security, SecurityTypedDict
from .service_deleteop import ServiceDeleteRequest, ServiceDeleteRequestTypedDict
from .service_listop import ServiceListRequest, ServiceListRequestTypedDict
from .servicecreaterequest import ServiceCreateRequest, ServiceCreateRequestTypedDict
from .serviceproperties import ServiceProperties
from .serviceresponse import ServiceResponse, ServiceResponseTypedDict
from .services_get_by_idop import (
    ServicesGetByIDRequest,
    ServicesGetByIDRequestTypedDict,
)
from .serviceupdaterequest import ServiceUpdateRequest, ServiceUpdateRequestTypedDict
from .session import Session, SessionTypedDict
from .session_full_summary_get_by_idop import (
    SessionFullSummaryGetByIDRequest,
    SessionFullSummaryGetByIDRequestTypedDict,
)
from .session_get_by_idop import SessionGetByIDRequest, SessionGetByIDRequestTypedDict
from .session_label_get_by_idop import (
    SessionLabelGetByIDRequest,
    SessionLabelGetByIDRequestTypedDict,
)
from .session_labels_listop import (
    SessionLabelsListRequest,
    SessionLabelsListRequestTypedDict,
)
from .session_latency_get_by_idop import (
    SessionLatencyGetByIDRequest,
    SessionLatencyGetByIDRequestTypedDict,
)
from .session_recording_streamop import (
    SessionRecordingStreamRequest,
    SessionRecordingStreamRequestTypedDict,
)
from .session_transcript_get_by_idop import (
    SessionTranscriptGetByIDRequest,
    SessionTranscriptGetByIDRequestTypedDict,
)
from .sessionaction import SessionAction, SessionActionTypedDict
from .sessiondata import SessionData, SessionDataTypedDict
from .sessionlabel import SessionLabel, SessionLabelTypedDict
from .sessionlabelcreate import SessionLabelCreate, SessionLabelCreateTypedDict
from .sessionlabelproperties import SessionLabelProperties
from .sessionmessage import SessionMessage, SessionMessageTypedDict
from .sessionproperties import SessionProperties
from .sessionrecordingresponse import (
    SessionRecordingResponse,
    SessionRecordingResponseTypedDict,
)
from .sessions_listop import SessionsListRequest, SessionsListRequestTypedDict
from .sessionsummaryresponse import (
    SessionSummaryResponse,
    SessionSummaryResponseTypedDict,
)
from .sessiontext import SessionText, SessionTextTypedDict
from .sessiontranscriptionresponse import (
    SessionTranscriptionResponse,
    SessionTranscriptionResponseTypedDict,
)
from .statictoolparameter import StaticToolParameter, StaticToolParameterTypedDict
from .statictoolparametertype import StaticToolParameterType
from .summaryentry import SummaryEntry, SummaryEntryTypedDict
from .supportedllm import SupportedLlm, SupportedLlmTypedDict
from .takeoutrequeststatus import TakeoutRequestStatus
from .takeouts_get_by_job_idop import (
    TakeoutsGetByJobIDRequest,
    TakeoutsGetByJobIDRequestTypedDict,
)
from .takeoutstatusresponse import TakeoutStatusResponse, TakeoutStatusResponseTypedDict
from .targetmodes import TargetModes
from .testmessage import TestMessage, TestMessageTypedDict
from .testmessageresponse import (
    Response,
    ResponseTypedDict,
    TestMessageResponse,
    TestMessageResponseTypedDict,
)
from .tool_deleteop import ToolDeleteRequest, ToolDeleteRequestTypedDict
from .tool_get_by_nameop import ToolGetByNameRequest, ToolGetByNameRequestTypedDict
from .tool_listop import ToolListRequest, ToolListRequestTypedDict
from .toolagentinfo import ToolAgentInfo, ToolAgentInfoTypedDict
from .toolargumentlocation import ToolArgumentLocation
from .toolcreaterequest import ToolCreateRequest, ToolCreateRequestTypedDict
from .tooldefinition import (
    Defaults,
    DefaultsTypedDict,
    ToolDefinition,
    ToolDefinitionTypedDict,
    Type,
)
from .tooldetailresponse import ToolDetailResponse, ToolDetailResponseTypedDict
from .toolfunction import ToolFunction, ToolFunctionTypedDict
from .toolhttpendpoint import ToolHTTPEndpoint, ToolHTTPEndpointTypedDict
from .toolhttpmethod import ToolHTTPMethod
from .toolparameterdefault import ToolParameterDefault, ToolParameterDefaultTypedDict
from .toolparametertransform import (
    Action,
    ToolParameterTransform,
    ToolParameterTransformTypedDict,
)
from .toolparametertransformcondition import (
    ToolParameterTransformCondition,
    ToolParameterTransformConditionTypedDict,
)
from .toolpromptinfo import ToolPromptInfo, ToolPromptInfoTypedDict
from .toolproperties import ToolProperties
from .toolresponse import ToolResponse, ToolResponseTypedDict
from .toolresultdata import ToolResultData, ToolResultDataTypedDict
from .toolupdaterequest import ToolUpdateRequest, ToolUpdateRequestTypedDict
from .ttsprovider import TtsProvider
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)

# Pydantic models with forward references
ChannelTargetResponse.model_rebuild()
AgentResponse.model_rebuild()

__all__ = [
    "APIError",
    "Action",
    "AgentCreate",
    "AgentCreateTypedDict",
    "AgentDeleteRequest",
    "AgentDeleteRequestTypedDict",
    "AgentGetByIDRequest",
    "AgentGetByIDRequestTypedDict",
    "AgentLanguage",
    "AgentLanguageTypedDict",
    "AgentListRequest",
    "AgentListRequestTypedDict",
    "AgentProperties",
    "AgentResponse",
    "AgentResponseTypedDict",
    "AgentSttProvider",
    "AgentToolDefaults",
    "AgentToolDefaultsTypedDict",
    "AgentToolFieldDefault",
    "AgentToolFieldDefaultTypedDict",
    "AgentUpdate",
    "AgentUpdateTypedDict",
    "AgentVoice",
    "AgentVoiceDisplayName",
    "AgentVoiceGender",
    "AgentVoiceModel",
    "AgentVoiceTypedDict",
    "AgentVoiceVarName",
    "AgentWaitSound",
    "Attributes",
    "AttributesTypedDict",
    "AvailableTarget",
    "AvailableTargetProperties",
    "AvailableTargetTypedDict",
    "AvailableTargetsRequest",
    "AvailableTargetsRequestTypedDict",
    "BatchDetails",
    "BatchDetailsTypedDict",
    "BatchProperties",
    "BatchStatus",
    "BodyOutboundBatchDelete",
    "BodyOutboundBatchDeleteTypedDict",
    "BodyOutboundBatchUpload",
    "BodyOutboundBatchUploadTypedDict",
    "CampaignProperties",
    "Channel",
    "ChannelProperties",
    "ChannelServices",
    "ChannelTargetCreateRequest",
    "ChannelTargetCreateRequestTypedDict",
    "ChannelTargetProperties",
    "ChannelTargetResponse",
    "ChannelTargetResponseTypedDict",
    "ChannelTargetUpdateRequest",
    "ChannelTargetUpdateRequestTypedDict",
    "ChannelTargetsCreateRequest",
    "ChannelTargetsCreateRequestTypedDict",
    "ChannelTargetsDeleteRequest",
    "ChannelTargetsDeleteRequestTypedDict",
    "ChannelTargetsGetByIDRequest",
    "ChannelTargetsGetByIDRequestTypedDict",
    "ChannelTargetsListRequest",
    "ChannelTargetsListRequestTypedDict",
    "ChannelTargetsUpdateRequest",
    "ChannelTargetsUpdateRequestTypedDict",
    "ChannelTypedDict",
    "ChannelsListRequest",
    "ChannelsListRequestTypedDict",
    "CommunicationBatch",
    "CommunicationBatchInput",
    "CommunicationBatchInputTypedDict",
    "CommunicationBatchTypedDict",
    "CommunicationRequest",
    "CommunicationRequestRequestVariables",
    "CommunicationRequestRequestVariablesTypedDict",
    "CommunicationRequestResult",
    "CommunicationRequestResultRequestVariables",
    "CommunicationRequestResultRequestVariablesTypedDict",
    "CommunicationRequestResultTypedDict",
    "CommunicationRequestTypedDict",
    "Conversation",
    "ConversationProperties",
    "ConversationTypedDict",
    "ConversationsListRequest",
    "ConversationsListRequestTypedDict",
    "CreateTakeoutResponse",
    "CreateTakeoutResponseTypedDict",
    "CustomMessageCreateRequest",
    "CustomMessageCreateRequestTypedDict",
    "CustomMessageGetByIDRequest",
    "CustomMessageGetByIDRequestTypedDict",
    "CustomMessageProperties",
    "CustomMessageResponse",
    "CustomMessageResponseTypedDict",
    "CustomMessageRule",
    "CustomMessageRuleTypedDict",
    "CustomMessageUpdateRequest",
    "CustomMessageUpdateRequestTypedDict",
    "CustomMessagesDeleteRequest",
    "CustomMessagesDeleteRequestTypedDict",
    "CustomMessagesListRequest",
    "CustomMessagesListRequestTypedDict",
    "Dashboard",
    "DashboardProperties",
    "DashboardResponse",
    "DashboardResponseTypedDict",
    "DashboardTokenResponse",
    "DashboardTokenResponseTypedDict",
    "DashboardTypedDict",
    "DataSourceCreateRequest",
    "DataSourceCreateRequestTypedDict",
    "DataSourceDetailResponse",
    "DataSourceDetailResponseTypedDict",
    "DataSourceMetadataResponse",
    "DataSourceMetadataResponseTypedDict",
    "DataSourceProperties",
    "DataSourceUpdateRequest",
    "DataSourceUpdateRequestTypedDict",
    "DataSourcesDeleteRequest",
    "DataSourcesDeleteRequestTypedDict",
    "DataSourcesGetByIDRequest",
    "DataSourcesGetByIDRequestTypedDict",
    "DataSourcesListRequest",
    "DataSourcesListRequestTypedDict",
    "DayOfWeek",
    "Defaults",
    "DefaultsTypedDict",
    "DialogMessage",
    "DialogMessageTypedDict",
    "DialogRole",
    "DialogToolCall",
    "DialogToolCallTypedDict",
    "Event",
    "EventProperties",
    "EventTypedDict",
    "EventsListRequest",
    "EventsListRequestTypedDict",
    "File",
    "FileTypedDict",
    "GenerateSessionRecordingUrlsRequest",
    "GenerateSessionRecordingUrlsRequestTypedDict",
    "GetSessionDataBySessionIDRequest",
    "GetSessionDataBySessionIDRequestTypedDict",
    "GetSessionDataBySidRequest",
    "GetSessionDataBySidRequestTypedDict",
    "GetSessionToolCallResultByIDRequest",
    "GetSessionToolCallResultByIDRequestTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "IncidentCreateRequest",
    "IncidentCreateRequestTypedDict",
    "IncidentDeleteRequest",
    "IncidentDeleteRequestTypedDict",
    "IncidentGetByIDRequest",
    "IncidentGetByIDRequestTypedDict",
    "IncidentListRequest",
    "IncidentListRequestTypedDict",
    "IncidentOrganizationResponse",
    "IncidentOrganizationResponseTypedDict",
    "IncidentProperties",
    "IncidentResponse",
    "IncidentResponseTypedDict",
    "IncidentUpdateRequest",
    "IncidentUpdateRequestTypedDict",
    "InsightToolDefinition",
    "InsightToolDefinitionTypedDict",
    "InsightToolGetByIDRequest",
    "InsightToolGetByIDRequestTypedDict",
    "InsightToolInput",
    "InsightToolInputToolArguments",
    "InsightToolInputToolArgumentsTypedDict",
    "InsightToolInputTypedDict",
    "InsightToolListRequest",
    "InsightToolListRequestTypedDict",
    "InsightToolOutput",
    "InsightToolOutputToolArguments",
    "InsightToolOutputToolArgumentsTypedDict",
    "InsightToolOutputTypedDict",
    "InsightToolProperties",
    "InsightToolTestInput",
    "InsightToolTestInputTypedDict",
    "InsightWorkflowInput",
    "InsightWorkflowInputConditions",
    "InsightWorkflowInputConditionsTypedDict",
    "InsightWorkflowInputTypedDict",
    "InsightWorkflowOutput",
    "InsightWorkflowOutputConditions",
    "InsightWorkflowOutputConditionsTypedDict",
    "InsightWorkflowOutputTypedDict",
    "InsightWorkflowProperties",
    "Insights",
    "InsightsListRequest",
    "InsightsListRequestTypedDict",
    "InsightsOutput",
    "InsightsOutputTypedDict",
    "InsightsProperties",
    "InsightsToolUpdateRequest",
    "InsightsToolUpdateRequestTypedDict",
    "InsightsTypedDict",
    "InsightsWorkflowDeleteRequest",
    "InsightsWorkflowDeleteRequestTypedDict",
    "InsightsWorkflowGetByIDRequest",
    "InsightsWorkflowGetByIDRequestTypedDict",
    "InsightsWorkflowListRequest",
    "InsightsWorkflowListRequestTypedDict",
    "InsightsWorkflowQueueSession",
    "InsightsWorkflowQueueSessionTypedDict",
    "InsightsWorkflowUpdateRequest",
    "InsightsWorkflowUpdateRequestTypedDict",
    "InspectLatencyResponse",
    "InspectLatencyResponseTypedDict",
    "InternalTool",
    "InternalToolTypedDict",
    "JSONValue",
    "JSONValueTypedDict",
    "LanguageCode",
    "LanguageConfig",
    "LanguageConfigTypedDict",
    "LanguageGroupAgentInfo",
    "LanguageGroupAgentInfoTypedDict",
    "LanguageGroupCreateRequest",
    "LanguageGroupCreateRequestTypedDict",
    "LanguageGroupProperties",
    "LanguageGroupResponse",
    "LanguageGroupResponseTypedDict",
    "LanguageGroupUpdateRequest",
    "LanguageGroupUpdateRequestTypedDict",
    "LanguageGroupsDeleteRequest",
    "LanguageGroupsDeleteRequestTypedDict",
    "LanguageGroupsGetByIDRequest",
    "LanguageGroupsGetByIDRequestTypedDict",
    "LanguageGroupsListRequest",
    "LanguageGroupsListRequestTypedDict",
    "LatencyCategory",
    "LatencyEntry",
    "LatencyEntryTypedDict",
    "LatencyUnitType",
    "ListResponseAgentResponse",
    "ListResponseAgentResponseTypedDict",
    "ListResponseAvailableTarget",
    "ListResponseAvailableTargetTypedDict",
    "ListResponseChannel",
    "ListResponseChannelTargetResponse",
    "ListResponseChannelTargetResponseTypedDict",
    "ListResponseChannelTypedDict",
    "ListResponseCommunicationBatch",
    "ListResponseCommunicationBatchTypedDict",
    "ListResponseConversation",
    "ListResponseConversationTypedDict",
    "ListResponseCustomMessageResponse",
    "ListResponseCustomMessageResponseTypedDict",
    "ListResponseDashboardResponse",
    "ListResponseDashboardResponseTypedDict",
    "ListResponseDataSourceMetadataResponse",
    "ListResponseDataSourceMetadataResponseTypedDict",
    "ListResponseEvent",
    "ListResponseEventTypedDict",
    "ListResponseIncidentResponse",
    "ListResponseIncidentResponseTypedDict",
    "ListResponseInsightToolOutput",
    "ListResponseInsightToolOutputTypedDict",
    "ListResponseInsightWorkflowOutput",
    "ListResponseInsightWorkflowOutputTypedDict",
    "ListResponseInsightsOutput",
    "ListResponseInsightsOutputTypedDict",
    "ListResponseLanguageGroupResponse",
    "ListResponseLanguageGroupResponseTypedDict",
    "ListResponseOutboundCampaign",
    "ListResponseOutboundCampaignTypedDict",
    "ListResponsePromptResponse",
    "ListResponsePromptResponseTypedDict",
    "ListResponseServiceResponse",
    "ListResponseServiceResponseTypedDict",
    "ListResponseSession",
    "ListResponseSessionLabel",
    "ListResponseSessionLabelTypedDict",
    "ListResponseSessionTypedDict",
    "ListResponseToolResponse",
    "ListResponseToolResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "OrderByDirection",
    "OutboundBatchAddRequest",
    "OutboundBatchAddRequestTypedDict",
    "OutboundBatchDeleteRequest",
    "OutboundBatchDeleteRequestTypedDict",
    "OutboundBatchGetByIDRequest",
    "OutboundBatchGetByIDRequestTypedDict",
    "OutboundBatchListRequest",
    "OutboundBatchListRequestTypedDict",
    "OutboundBatchRemoveRequest",
    "OutboundBatchRemoveRequestTypedDict",
    "OutboundBatchResultsRequest",
    "OutboundBatchResultsRequestTypedDict",
    "OutboundBatchUpdateRequest",
    "OutboundBatchUpdateRequestTypedDict",
    "OutboundBatchUploadRequest",
    "OutboundBatchUploadRequestTypedDict",
    "OutboundCampaign",
    "OutboundCampaignCampaignVariables",
    "OutboundCampaignCampaignVariablesTypedDict",
    "OutboundCampaignGetByIDRequest",
    "OutboundCampaignGetByIDRequestTypedDict",
    "OutboundCampaignInput",
    "OutboundCampaignInputCampaignVariables",
    "OutboundCampaignInputCampaignVariablesTypedDict",
    "OutboundCampaignInputTypedDict",
    "OutboundCampaignListRequest",
    "OutboundCampaignListRequestTypedDict",
    "OutboundCampaignTypedDict",
    "OutboundCampaignUpdateRequest",
    "OutboundCampaignUpdateRequestTypedDict",
    "PostGetDashboardRequest",
    "PostGetDashboardRequestTypedDict",
    "PostListDashboardRequest",
    "PostListDashboardRequestTypedDict",
    "PromptCreateRequest",
    "PromptCreateRequestTypedDict",
    "PromptHistory",
    "PromptHistoryTypedDict",
    "PromptLlmConfig",
    "PromptLlmConfigTypedDict",
    "PromptLlmProvider",
    "PromptProperties",
    "PromptResponse",
    "PromptResponseTypedDict",
    "PromptUpdateRequest",
    "PromptUpdateRequestTypedDict",
    "PromptsDeleteRequest",
    "PromptsDeleteRequestTypedDict",
    "PromptsGetByIDRequest",
    "PromptsGetByIDRequestTypedDict",
    "PromptsHistoryRequest",
    "PromptsHistoryRequestTypedDict",
    "PromptsListRequest",
    "PromptsListRequestTypedDict",
    "Response",
    "ResponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "ServiceCreateRequest",
    "ServiceCreateRequestTypedDict",
    "ServiceDeleteRequest",
    "ServiceDeleteRequestTypedDict",
    "ServiceListRequest",
    "ServiceListRequestTypedDict",
    "ServiceProperties",
    "ServiceResponse",
    "ServiceResponseTypedDict",
    "ServiceUpdateRequest",
    "ServiceUpdateRequestTypedDict",
    "ServicesGetByIDRequest",
    "ServicesGetByIDRequestTypedDict",
    "Session",
    "SessionAction",
    "SessionActionTypedDict",
    "SessionData",
    "SessionDataTypedDict",
    "SessionFullSummaryGetByIDRequest",
    "SessionFullSummaryGetByIDRequestTypedDict",
    "SessionGetByIDRequest",
    "SessionGetByIDRequestTypedDict",
    "SessionLabel",
    "SessionLabelCreate",
    "SessionLabelCreateTypedDict",
    "SessionLabelGetByIDRequest",
    "SessionLabelGetByIDRequestTypedDict",
    "SessionLabelProperties",
    "SessionLabelTypedDict",
    "SessionLabelsListRequest",
    "SessionLabelsListRequestTypedDict",
    "SessionLatencyGetByIDRequest",
    "SessionLatencyGetByIDRequestTypedDict",
    "SessionMessage",
    "SessionMessageTypedDict",
    "SessionProperties",
    "SessionRecordingResponse",
    "SessionRecordingResponseTypedDict",
    "SessionRecordingStreamRequest",
    "SessionRecordingStreamRequestTypedDict",
    "SessionSummaryResponse",
    "SessionSummaryResponseTypedDict",
    "SessionText",
    "SessionTextTypedDict",
    "SessionTranscriptGetByIDRequest",
    "SessionTranscriptGetByIDRequestTypedDict",
    "SessionTranscriptionResponse",
    "SessionTranscriptionResponseTypedDict",
    "SessionTypedDict",
    "SessionsListRequest",
    "SessionsListRequestTypedDict",
    "StaticToolParameter",
    "StaticToolParameterType",
    "StaticToolParameterTypedDict",
    "StatusCounts",
    "StatusCountsTypedDict",
    "SummaryEntry",
    "SummaryEntryTypedDict",
    "SupportedLlm",
    "SupportedLlmTypedDict",
    "TakeoutRequestStatus",
    "TakeoutStatusResponse",
    "TakeoutStatusResponseTypedDict",
    "TakeoutsGetByJobIDRequest",
    "TakeoutsGetByJobIDRequestTypedDict",
    "TargetModes",
    "TestMessage",
    "TestMessageResponse",
    "TestMessageResponseTypedDict",
    "TestMessageTypedDict",
    "ToolAgentInfo",
    "ToolAgentInfoTypedDict",
    "ToolArgumentLocation",
    "ToolCreateRequest",
    "ToolCreateRequestTypedDict",
    "ToolDefinition",
    "ToolDefinitionTypedDict",
    "ToolDeleteRequest",
    "ToolDeleteRequestTypedDict",
    "ToolDetailResponse",
    "ToolDetailResponseTypedDict",
    "ToolFunction",
    "ToolFunctionTypedDict",
    "ToolGetByNameRequest",
    "ToolGetByNameRequestTypedDict",
    "ToolHTTPEndpoint",
    "ToolHTTPEndpointTypedDict",
    "ToolHTTPMethod",
    "ToolListRequest",
    "ToolListRequestTypedDict",
    "ToolParameterDefault",
    "ToolParameterDefaultTypedDict",
    "ToolParameterTransform",
    "ToolParameterTransformCondition",
    "ToolParameterTransformConditionTypedDict",
    "ToolParameterTransformTypedDict",
    "ToolParameters",
    "ToolParametersTypedDict",
    "ToolPromptInfo",
    "ToolPromptInfoTypedDict",
    "ToolProperties",
    "ToolResponse",
    "ToolResponseTypedDict",
    "ToolResultData",
    "ToolResultDataTypedDict",
    "ToolResultSet",
    "ToolResultSetTypedDict",
    "ToolUpdateRequest",
    "ToolUpdateRequestTypedDict",
    "TtsProvider",
    "Type",
    "ValidationError",
    "ValidationErrorTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class DialogToolCallTypedDict(TypedDict):
    tool_call_id: str
    r"""Tool call ID"""
    tool_name: str
    r"""Tool name"""
    tool_arguments: Any
    r"""Tool arguments"""
    timestamp: datetime
    r"""Tool call timestamp"""


class DialogToolCall(BaseModel):
    tool_call_id: str
    r"""Tool call ID"""

    tool_name: str
    r"""Tool name"""

    tool_arguments: Any
    r"""Tool arguments"""

    timestamp: datetime
    r"""Tool call timestamp"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insighttooloutput import InsightToolOutput, InsightToolOutputTypedDict
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class InsightWorkflowOutputConditionsTypedDict(TypedDict):
    r"""Conditions for insight workflow to trigger on a given call recording."""


class InsightWorkflowOutputConditions(BaseModel):
    r"""Conditions for insight workflow to trigger on a given call recording."""


class InsightWorkflowOutputTypedDict(TypedDict):
    r"""Response model for an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""
    description: str
    r"""Text description of insight workflow"""
    insight_tool_ids: List[int]
    r"""List of IDs of insight tools used in the workflow"""
    conditions: InsightWorkflowOutputConditionsTypedDict
    r"""Conditions for insight workflow to trigger on a given call recording."""
    status: str
    r"""Status of the insight workflow"""
    id: int
    r"""Internal ID of the insight workflow"""
    insight_tools: List[InsightToolOutputTypedDict]
    r"""List of insight tools used in the workflow"""
    last_updated_by: str
    r"""Email of user who last updated Insight Workflow"""
    created_at: NotRequired[datetime]
    r"""Timestamp at which the insight workflow was created"""
    updated_at: NotRequired[datetime]
    r"""Timestamp of most recent update to the insight workflow"""


class InsightWorkflowOutput(BaseModel):
    r"""Response model for an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""

    description: str
    r"""Text description of insight workflow"""

    insight_tool_ids: List[int]
    r"""List of IDs of insight tools used in the workflow"""

    conditions: InsightWorkflowOutputConditions
    r"""Conditions for insight workflow to trigger on a given call recording."""

    status: str
    r"""Status of the insight workflow"""

    id: int
    r"""Internal ID of the insight workflow"""

    insight_tools: List[InsightToolOutput]
    r"""List of insight tools used in the workflow"""

    last_updated_by: str
    r"""Email of user who last updated Insight Workflow"""

    created_at: Optional[datetime] = None
    r"""Timestamp at which the insight workflow was created"""

    updated_at: Optional[datetime] = None
    r"""Timestamp of most recent update to the insight workflow"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class OutboundBatchResultsRequestTypedDict(TypedDict):
    batch_id: str
    reference_id: NotRequired[str]
    status: NotRequired[str]


class OutboundBatchResultsRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    reference_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    status: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseTypedDict(TypedDict):
    r"""The response from the agent"""


class Response(BaseModel):
    r"""The response from the agent"""


class TestMessageResponseTypedDict(TypedDict):
    r"""Response from an agent in a test chat."""

    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    test_id: str
    r"""Channel-manager-side ID of the session (see Session.channel_manager_sid)"""
    agent_id: str
    r"""ID of the agent with which the chat is taking place"""
    text: NotRequired[str]
    r"""The text of the message that elicited the response"""
    response: NotRequired[ResponseTypedDict]
    r"""The response from the agent"""
    response_text: NotRequired[str]
    r"""The text of the response"""


class TestMessageResponse(BaseModel):
    r"""Response from an agent in a test chat."""

    __test__ = False

    test_id: str
    r"""Channel-manager-side ID of the session (see Session.channel_manager_sid)"""

    agent_id: str
    r"""ID of the agent with which the chat is taking place"""

    text: Optional[str] = None
    r"""The text of the message that elicited the response"""

    response: Optional[Response] = None
    r"""The response from the agent"""

    response_text: Optional[str] = None
    r"""The text of the response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceModel(str, Enum):
    r"""Model for an agent voice."""

    MULTILINGUAL_V2 = "Multilingual_v2"
    NEURAL2 = "Neural2"
    STANDARD = "Standard"
    STUDIO = "Studio"
    WAVE_NET = "WaveNet"
    WHISPER = "Whisper"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ServiceCreateRequestTypedDict(TypedDict):
    r"""Request model to create a service."""

    name: str
    r"""The name of the service"""
    description: str
    r"""The description of the service"""


class ServiceCreateRequest(BaseModel):
    r"""Request model to create a service."""

    name: str
    r"""The name of the service"""

    description: str
    r"""The description of the service"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightsWorkflowQueueSessionTypedDict(TypedDict):
    r"""Session identifier for workflow queue."""

    workflow_name: str
    r"""Unique name for workflow"""
    session_id_list: List[int]
    r"""List of session identifiers"""


class InsightsWorkflowQueueSession(BaseModel):
    r"""Session identifier for workflow queue."""

    workflow_name: str
    r"""Unique name for workflow"""

    session_id_list: List[int]
    r"""List of session identifiers"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TakeoutRequestStatus(str, Enum):
    r"""Status of a takeout request."""

    PENDING = "pending"
    IN_PROGRESS = "in_progress"
    COMPLETED = "completed"
    FAILED = "failed"
    CANCELED = "canceled"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agentvoicedisplayname import AgentVoiceDisplayName
from .languagecode import LanguageCode
from .ttsprovider import TtsProvider
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class LanguageConfigTypedDict(TypedDict):
    r"""Voice and DTMF configurations for a language in a language group. List of available voices
    and their supported languages can be fetched from `GET /agents/voices/available/`.
    """

    language_code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""
    voice_provider: TtsProvider
    r"""TTS provider for an agent voice."""
    voice_display_name: AgentVoiceDisplayName
    r"""Display names of voices that Syllable supports."""
    dtmf_code: int
    r"""DTMF code that should be used for the language in the menu generated from the language group"""


class LanguageConfig(BaseModel):
    r"""Voice and DTMF configurations for a language in a language group. List of available voices
    and their supported languages can be fetched from `GET /agents/voices/available/`.
    """

    language_code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""

    voice_provider: TtsProvider
    r"""TTS provider for an agent voice."""

    voice_display_name: AgentVoiceDisplayName
    r"""Display names of voices that Syllable supports."""

    dtmf_code: int
    r"""DTMF code that should be used for the language in the menu generated from the language group"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightWorkflowInputConditionsTypedDict(TypedDict):
    r"""Conditions for insight workflow to trigger on a given call recording."""


class InsightWorkflowInputConditions(BaseModel):
    r"""Conditions for insight workflow to trigger on a given call recording."""


class InsightWorkflowInputTypedDict(TypedDict):
    r"""Request model to create/update an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""
    description: str
    r"""Text description of insight workflow"""
    insight_tool_ids: List[int]
    r"""List of IDs of insight tools used in the workflow"""
    conditions: InsightWorkflowInputConditionsTypedDict
    r"""Conditions for insight workflow to trigger on a given call recording."""
    status: str
    r"""Status of the insight workflow"""


class InsightWorkflowInput(BaseModel):
    r"""Request model to create/update an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""

    description: str
    r"""Text description of insight workflow"""

    insight_tool_ids: List[int]
    r"""List of IDs of insight tools used in the workflow"""

    conditions: InsightWorkflowInputConditions
    r"""Conditions for insight workflow to trigger on a given call recording."""

    status: str
    r"""Status of the insight workflow"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightToolTestInputTypedDict(TypedDict):
    r"""Request model to test an insight tool."""

    tool_name: str
    r"""Human readable name of insight tool"""
    session_id: int
    r"""The session ID of the session to run the tool against"""


class InsightToolTestInput(BaseModel):
    r"""Request model to test an insight tool."""

    tool_name: str
    r"""Human readable name of insight tool"""

    session_id: int
    r"""The session ID of the session to run the tool against"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .communicationbatch import CommunicationBatch, CommunicationBatchTypedDict
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OutboundBatchUpdateRequestTypedDict(TypedDict):
    batch_id: str
    communication_batch: CommunicationBatchTypedDict


class OutboundBatchUpdateRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    communication_batch: Annotated[
        CommunicationBatch,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from syllable_sdk.batches import Batches
from syllable_sdk.campaigns import Campaigns


class Outbound(BaseSDK):
    batches: Batches
    r"""Operations related to outbound campaign batches"""
    campaigns: Campaigns
    r"""Operations related to outbound message campaigns"""

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.batches = Batches(self.sdk_configuration)
        self.campaigns = Campaigns(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class IncidentOrganizationResponseTypedDict(TypedDict):
    id: int
    name: str
    display_name: str


class IncidentOrganizationResponse(BaseModel):
    id: int

    name: str

    display_name: str
